@@ -32,35 +32,36 @@ test_that("GetBibEntryWithDOIs continues if some DOIs not found", {
                    "[Uu]nable to retrieve bibliographic")
 })
 
-test_that("GetDOIs retrieves DOIs", {
-    skip_on_cran()
-    if (httr::http_error("https://search.crossref.org"))
-        skip("Couldn't connect to search.crossref.org")
+## test_that("GetDOIs retrieves DOIs", {
+##     skip_on_cran()
+##     if (httr::http_error("https://search.crossref.org"))
+##         skip("Couldn't connect to search.crossref.org")
 
-    BibOptions(check.entries = FALSE, sorting = "none")
-    bib <- ReadBib(system.file("Bib", "RJC.bib",
-                               package = "RefManageR"))[[3:4]]
-    out <- GetDOIs(bib)
+##     BibOptions(check.entries = FALSE, sorting = "none")
+##     bib <- ReadBib(system.file("Bib", "RJC.bib",
+##                                package = "RefManageR"))[[3:4]]
+##     out <- GetDOIs(bib)
 
-    expect_is(out, "BibEntry")
-    expect_equal(length(out), 2L)
-    dois.out <- setNames(unlist(out$doi), NULL)
-    expect_equal(dois.out[1], "10.1093/bioinformatics/btt608")
-    expect_message(GetDOIs(out[[1]]), "All entries already have DOIs")
-    ## expect_message(GetDOIs(out[[2]]), "No matches.")
-})
+##     expect_is(out, "BibEntry")
+##     expect_equal(length(out), 2L)
+##     dois.out <- setNames(unlist(out$doi), NULL)
+##     expect_equal(dois.out[1], "10.1093/bioinformatics/btt608")
+##     expect_message(GetDOIs(out[[1]]), "All entries already have DOIs")
+##     ## expect_message(GetDOIs(out[[2]]), "No matches.")
+## })
 
 old.opts <- BibOptions(check.entries = FALSE)
 
-test_that("ReadCrossRef *old* API retrieves queries successfully", {
+test_that("ReadCrossRef *old* API warns and uses new API", {
     skip_on_cran()
     if (httr::http_error("https://search.crossref.org/"))
         skip("Couldn't connect to search.crossref.org")
 
     BibOptions(check.entries = FALSE, sorting = "none")
-    out <- ReadCrossRef(query = 'gelman bayesian', limit = 2,
+    expect_warning(out <- ReadCrossRef(query = 'gelman bayesian', limit = 2,
                         sort = "relevance",
-                        min.relevance = 80, use.old.api = TRUE)
+                        min.relevance = 80, use.old.api = TRUE),
+                   "old CrossRef API is no longer support")
 
     expect_is(out, "BibEntry")
     expect_equal(length(out), 2L)
