@@ -9,8 +9,8 @@ context("PubMed")
 test_that("GetPubMedByID can process books (#2)", {
   skip_on_cran()
   if (httr::http_error("https://eutils.ncbi.nlm.nih.gov/"))
-      skip("Couldn't connect to Entrez")
-  
+    skip("Couldn't connect to Entrez")
+
   test <- GetPubMedByID(c("24977996", "24921111"))
   if (length(test))
     expect_true(length(test) == 2L)
@@ -19,9 +19,10 @@ test_that("GetPubMedByID can process books (#2)", {
 test_that("GetPubMedByID uses collective name if authors missing (#2)", {
   skip_on_cran()
   if (httr::http_error("https://eutils.ncbi.nlm.nih.gov/"))
-      skip("Couldn't connect to Entrez")
-  
-  test <- GetPubMedByID(c(11678951, 15373863))
+    skip("Couldn't connect to Entrez")
+  Sys.sleep(2)
+
+  try_again(3, test <- GetPubMedByID(c(11678951, 15373863)))
   if (length(test)){
     authors <- unlist(test$author)
     expect_true(length(authors) == 2L)
@@ -32,8 +33,10 @@ test_that("GetPubMedByID warns if authors missing (#3)", {
   skip_on_cran()
   if (httr::http_error("https://eutils.ncbi.nlm.nih.gov/"))
     skip("Couldn't connect to Entrez")
+  Sys.sleep(2)
 
-  expect_warning(GetPubMedByID("7936917"))
+  BibOptions(check.entries = FALSE)
+  expect_warning(try_again(3, GetPubMedByID("7936917")))
 })
 
 test_that("LookupPubMedID successfully retrieves and add ID's'", {
@@ -41,11 +44,22 @@ test_that("LookupPubMedID successfully retrieves and add ID's'", {
     file.name <- system.file("Bib", "RJC.bib", package="RefManageR")
     bib <- ReadBib(file.name)
     if (httr::http_error("https://eutils.ncbi.nlm.nih.gov/"))
-        skip("Couldn't connect to Entrez")
-    out <- LookupPubMedID(bib[[101:102]])
+      skip("Couldn't connect to Entrez")
+    Sys.sleep(2)
+    try_again(3, out <- LookupPubMedID(bib[[101:102]]))
     expect_equal(length(out), 2L)
     ids <- setNames(unlist(out$eprint), NULL)
     expect_equal(ids, c("19381352", "19444335"))
-    expect_message(LookupPubMedID(bib, 453), "No PubMed ID's found")
+    Sys.sleep(2)
+    expect_message(try_again(3, LookupPubMedID(bib, 453)), "No PubMed ID's found")
 })
 
+test_that("GetPubMedByID reading of years/months (#52)", {
+  skip_on_cran()
+  if (httr::http_error("https://eutils.ncbi.nlm.nih.gov/"))
+    skip("Couldn't connect to Entrez")
+  Sys.sleep(2)
+  try_again(3, bib <- GetPubMedByID("23891459"))
+  expect_equal(bib$year, "2013")
+  expect_equal(bib$month, "07")
+})
